@@ -340,14 +340,15 @@ class LinearSVMAlgorithmWithPrecomputedKernel(ClassificationAlgorithm):
         svc.fit(kernel_train, y_train)
         y_hat_train = svc.predict(kernel_train)
         y_hat = svc.predict(x_test)
+        spare_score = svc.decision_function(x_test)
         proba_test_index1 = svc.predict_proba(x_test)[:, 1]
         auc = roc_auc_score(y_test, proba_test_index1)
 
-        return svc, y_hat, auc, y_hat_train, proba_test_index1
+        return svc, y_hat, auc, y_hat_train, proba_test_index1, spare_score
 
     def _grid_search(self, kernel_train, x_test, y_train, y_test, c):
 
-        _, y_hat, _, _, _ = self._launch_svc(kernel_train, x_test, y_train, y_test, c)
+        _, y_hat, _, _, _, _ = self._launch_svc(kernel_train, x_test, y_train, y_test, c)
         ba = evaluate_prediction(y_test, y_hat)['balanced_accuracy']
 
         return ba
@@ -406,7 +407,7 @@ class LinearSVMAlgorithmWithPrecomputedKernel(ClassificationAlgorithm):
         x_test = self._kernel[test_index, :][:, train_index]
         y_train, y_test = self._y[train_index], self._y[test_index]
 
-        _, y_hat, auc, y_hat_train, proba_test_index1 = self._launch_svc(outer_kernel, x_test, y_train, y_test, best_parameter['c'])
+        _, y_hat, auc, y_hat_train, proba_test_index1, spare_score = self._launch_svc(outer_kernel, x_test, y_train, y_test, best_parameter['c'])
 
         result = dict()
         result['best_parameter'] = best_parameter
@@ -420,6 +421,7 @@ class LinearSVMAlgorithmWithPrecomputedKernel(ClassificationAlgorithm):
         result['x_index'] = train_index
         result['auc'] = auc
         result['proba_test_index1'] = proba_test_index1
+        result['spare_score'] = spare_score
 
         return result
 
@@ -494,10 +496,11 @@ class LinearSVMAlgorithmWithPrecomputedKernelNestedFeatureSelection(Classificati
         svc.fit(kernel_train, y_train)
         y_hat_train = svc.predict(kernel_train)
         y_hat = svc.predict(x_test)
+        spare_score = svc.decision_function(x_test)
         proba_test_index1 = svc.predict_proba(x_test)[:, 1]
         auc = roc_auc_score(y_test, proba_test_index1)
 
-        return svc, y_hat, auc, y_hat_train, proba_test_index1
+        return svc, y_hat, auc, y_hat_train, proba_test_index1, spare_score
 
     def _grid_search(self, kernel_train, x_test, y_train, y_test, c):
 
@@ -582,7 +585,7 @@ class LinearSVMAlgorithmWithPrecomputedKernelNestedFeatureSelection(Classificati
         x_test = self._kernel[test_index, :][:, train_index]
         y_train, y_test = self._y[train_index], self._y[test_index]
 
-        _, y_hat, auc, y_hat_train, proba_test_index1 = self._launch_svc(outer_kernel, x_test, y_train, y_test, best_parameter['c'])
+        _, y_hat, auc, y_hat_train, proba_test_index1, spare_score = self._launch_svc(outer_kernel, x_test, y_train, y_test, best_parameter['c'])
 
         result = dict()
         result['best_parameter'] = best_parameter
@@ -596,6 +599,7 @@ class LinearSVMAlgorithmWithPrecomputedKernelNestedFeatureSelection(Classificati
         result['x_index'] = train_index
         result['auc'] = auc
         result['proba_test_index1'] = proba_test_index1
+        result['spare_score'] = spare_score
 
         return result
 
@@ -804,7 +808,8 @@ class RepeatedHoldOut(ClassificationValidation):
                                                        'y': self._split_results[iteration]['y'],
                                                        'y_hat': self._split_results[iteration]['y_hat'],
                                                        'subject_index': self._split_results[iteration]['y_index'],
-                                                      'proba_test_index1': self._split_results[iteration]['proba_test_index1']})
+                                                      'proba_test_index1': self._split_results[iteration]['proba_test_index1'],
+                                                      'spare_score': self._split_results[iteration]['spare_score']})
             iteration_test_subjects_df.to_csv(os.path.join(iteration_dir, 'test_subjects.tsv'),
                                               index=False, sep='\t', encoding='utf-8')
             all_test_subjects_list.append(iteration_test_subjects_df)
