@@ -4,7 +4,12 @@ import os, pickle
 from sklearn.model_selection import StratifiedKFold, StratifiedShuffleSplit, KFold, ShuffleSplit
 from sklearn.cluster import KMeans
 from sklearn.metrics import adjusted_rand_score, accuracy_score
-from sklearn.metrics.ranking import roc_auc_score
+from packaging import version
+import sklearn
+if version.parse(sklearn.__version__) < version.parse("0.22.0"):
+    from sklearn.metrics.ranking import roc_auc_score
+else:
+    from sklearn.metrics import roc_auc_score
 from sklearn.svm import SVC
 from joblib import dump
 import pandas as pd
